pub struct TabPanel { /* private fields */ }Expand description
The TabPanel is an ease of use wrapper around a TabView and its TabBar.
Additionally the TabBar in the Panel can be horizontally aligned, by default it is set to be left aligned.
Example
use cursive_tabs::{Align, TabPanel};
use cursive::views::TextView;
use cursive::view::Nameable;
let mut tabs = TabPanel::new()
.with_tab(TextView::new("First").with_name("First"))
.with_tab(TextView::new("Second").with_name("Second"))
.with_bar_alignment(Align::Center);A TabView is also usable separately, so if you prefer the tabs without the TabBar and Panel around have a look at TabView.
Implementations
Sourceimpl TabPanel
impl TabPanel
Sourcepub fn new() -> Self
pub fn new() -> Self
Returns a new instance of a TabPanel.
Alignment is set by default to left, to change this use set_bar_alignment to change to any other HAlign provided by cursive.
Sourcepub fn active_tab(&self) -> Option<&str>
pub fn active_tab(&self) -> Option<&str>
Returns the current active tab of the TabView.
Note: Calls active_tab on the enclosed TabView.
Sourcepub fn active_view(&self) -> Option<&dyn View>
pub fn active_view(&self) -> Option<&dyn View>
Returns a reference to the underlying view.
Sourcepub fn active_view_mut(&mut self) -> Option<&mut dyn View>
pub fn active_view_mut(&mut self) -> Option<&mut dyn View>
Returns a mutable reference to the underlying view.
pub fn views(&self) -> Vec<&dyn View>
pub fn views_mut(&mut self) -> Vec<&mut dyn View>
Sourcepub fn set_active_tab(&mut self, id: &str) -> Result<(), IdNotFound>
pub fn set_active_tab(&mut self, id: &str) -> Result<(), IdNotFound>
Non-consuming variant to set the active tab in the TabView.
Note: Calls set_active_tab on the enclosed TabView.
Sourcepub fn with_active_tab(self, id: &str) -> Result<Self, Self>
pub fn with_active_tab(self, id: &str) -> Result<Self, Self>
Consuming & Chainable variant to set the active tab in the TabView.
Note: Calls set_active_tab on the enclosed TabView.
Sourcepub fn add_tab<T: View>(&mut self, view: NamedView<T>)
pub fn add_tab<T: View>(&mut self, view: NamedView<T>)
Non-consuming variant to add new tabs to the TabView.
Note: Calls add_tab on the enclosed TabView.
Sourcepub fn with_tab<T: View>(self, view: NamedView<T>) -> Self
pub fn with_tab<T: View>(self, view: NamedView<T>) -> Self
Consuming & Chainable variant to add a new tab.
Note: Calls add_tab on the enclosed TabView.
Sourcepub fn swap_tabs(&mut self, fst: &str, snd: &str)
pub fn swap_tabs(&mut self, fst: &str, snd: &str)
Swaps the given tab keys. If at least one of them cannot be found then no operation is performed
Sourcepub fn add_tab_at<T: View>(&mut self, view: NamedView<T>, pos: usize)
pub fn add_tab_at<T: View>(&mut self, view: NamedView<T>, pos: usize)
Non-consuming variant to add new tabs to the TabView at a certain position.
It is fail-safe, if the postion is greater than the amount of tabs, it is appended to the end.
Note: Calls add_tab_at on the enclosed TabView.
Sourcepub fn with_tab_at<T: View>(self, view: NamedView<T>, pos: usize) -> Self
pub fn with_tab_at<T: View>(self, view: NamedView<T>, pos: usize) -> Self
Consuming & Chainable variant to add a new tab at a certain position.
It is fail-safe, if the postion is greater than the amount of tabs, it is appended to the end.
Note: Calls add_tab_at on the enclosed TabView.
Sourcepub fn remove_tab(&mut self, id: &str) -> Result<(), IdNotFound>
pub fn remove_tab(&mut self, id: &str) -> Result<(), IdNotFound>
Remove a tab of the enclosed TabView.
Sourcepub fn with_bar_alignment(self, align: Align) -> Self
pub fn with_bar_alignment(self, align: Align) -> Self
Consumable & Chainable variant to set the bar alignment.
Sourcepub fn set_bar_alignment(&mut self, align: Align)
pub fn set_bar_alignment(&mut self, align: Align)
Non-consuming variant to set the bar alignment.
pub fn with_bar_placement(self, placement: Placement) -> Self
pub fn set_bar_placement(&mut self, placement: Placement)